@@ -2,6 +2,12 @@ from . import WeRoBot
 from .messages import WeChatMessage, TextMessage, ImageMessage, LocationMessage
 
 __all__ = ['WeTest']
+_kwargs = {
+    'msgid': 1234567890123456,
+    'touser': 'test',
+    'fromuser': 'test',
+    'time': 123456789,
+}
 
 
 class WeTest(object):
@@ -17,33 +23,15 @@ class WeTest(object):
 
 
 def make_text_message(content):
-    message = TextMessage(
-        'test',
-        'test',
-        0,
-        content
-    )
+    message = TextMessage(content, **_kwargs)
     return message
 
 
 def make_image_message(img):
-    message = ImageMessage(
-        'test',
-        'test',
-        0,
-        img
-    )
+    message = ImageMessage(img, **_kwargs)
     return message
 
 
 def make_location_message(x, y, scale, label):
-    message = LocationMessage(
-        'test',
-        'test',
-        0,
-        x,
-        y,
-        scale,
-        label
-    )
+    message = LocationMessage(x, y, scale, label, **_kwargs)
     return message
